/***************************************************************************
 *   Copyright (C) 2003 by Matteo Merli                                    *
 *   matteo@petaligrigi.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
 

#include "details.h"
//
#include "flat_button.h"

#include <kfileitem.h>
#include <kfilemetainfo.h>
#include <kapplication.h>
#include <dcopclient.h>
#include <dcopref.h>
#include <kdebug.h>

Details::Details(QWidget *parent, QBoxLayout *layout,
		 QString text, QString icon)
{
	header = new MyHeader(parent, layout, text, icon);
	
	QHBoxLayout *hbox;
	tFont.setPointSize( tFont.pointSize() - 1 );
	QFont bFont;
	bFont.setPointSize( tFont.pointSize() - 1 );
	bFont.setBold( true );

	/////////////// NAME ///////////////////////
	hbox = new QHBoxLayout( 0 );
	hbox->addSpacing(20);
	lIcon = new QLabel( header->mFrame );
	lIcon->setFixedSize(22, 22);
	lName = new QLabel( header->mFrame );
	lName->setFont( tFont );
	hbox->addWidget( lIcon );
	hbox->addSpacing(10);
	hbox->addWidget( lName );
	header->layout->addLayout( hbox );

	/////////////// TYPE //////////////////////////
	hbox = new QHBoxLayout( 0 );
	hbox->addSpacing(20);
	lType = new QLabel( header->mFrame );
	sType = new QLabel( header->mFrame );
	sType->setFont( bFont );
	lType->setFont( tFont );
	lType->setAlignment( Qt::AlignLeft );
	sType->setText( i18n("Type") + QString(" : ") );
	hbox->addWidget( sType );
	hbox->addSpacing(5);
	hbox->addWidget( lType );
	hbox->addStretch();
	header->layout->addLayout( hbox );

	//////////////// USER /////////////////////////
	hbox = new QHBoxLayout( 0 );
	hbox->addSpacing(20);
	lUser = new QLabel( header->mFrame );
	sUser = new QLabel( header->mFrame );
	sUser->setFont( bFont );
	lUser->setFont( tFont );
	lUser->setAlignment( Qt::AlignLeft );
	sUser->setText( i18n("User") + QString(" : ") );
	hbox->addWidget( sUser );
	hbox->addSpacing(5);
	hbox->addWidget( lUser );
	hbox->addStretch();
	header->layout->addLayout( hbox );
	
	//////////////// PERMISSIONS /////////////////////////
	hbox = new QHBoxLayout( 0 );
	hbox->addSpacing(20);
	lPermissions = new QLabel( header->mFrame );
	sPermissions = new QLabel( header->mFrame );
	sPermissions->setFont( bFont );
	lPermissions->setFont( tFont );
	lPermissions->setAlignment( Qt::AlignLeft );
	sPermissions->setText( i18n("Permissions")  + QString(" : ") );
	hbox->addWidget( sPermissions );
	hbox->addSpacing(5);
	hbox->addWidget( lPermissions );
	hbox->addStretch();
	header->layout->addLayout( hbox );
	
	///////////////// MODIFIED ///////////////////////
	hbox = new QHBoxLayout( 0 );
	hbox->addSpacing(20);
	lModified = new QLabel( header->mFrame );
	sModified = new QLabel( header->mFrame );
	sModified->setFont( bFont );
	lModified->setFont( tFont );
	lModified->setAlignment( Qt::AlignLeft );
	sModified->setText( i18n("Modified") + QString(" : ") );
	hbox->addWidget( sModified );
	hbox->addSpacing(5);
	hbox->addWidget( lModified );
	hbox->addStretch();
	header->layout->addLayout( hbox );
	
	///////////////// SIZE //////////////////////////////
	hbox = new QHBoxLayout( 0 );
	hbox->addSpacing(20);
	lSize = new QLabel( header->mFrame );
	sSize = new QLabel( header->mFrame );
	sSize->setFont( bFont );
	lSize->setFont( tFont );
	lSize->setAlignment( Qt::AlignLeft );
	sSize->setText( i18n("Size") + QString(" : ") );
	hbox->addWidget( sSize );
	hbox->addSpacing(5);
	hbox->addWidget( lSize );
	hbox->addStretch();
	header->layout->addLayout( hbox );
	
	header->layout->addSpacing( 10 );
	
	///////////////// META INFO //////////////////
	for (int i=0; i < 6; i++) {
		hbox = new QHBoxLayout( 0 );
		hbox->addSpacing(20);
		lInfo[i] = new QLabel( header->mFrame );
		sInfo[i] = new QLabel( header->mFrame );
		sInfo[i]->setFont( bFont );
		lInfo[i]->setFont( tFont );
		lInfo[i]->setAlignment( Qt::AlignLeft );
		hbox->addWidget( sInfo[i] );
		hbox->addSpacing(5);
		hbox->addWidget( lInfo[i] );
		hbox->addStretch();
		header->layout->addLayout( hbox );
	}
	
	
	connect( parent, SIGNAL( urlChanged(const KURL &) ),
		 this, SLOT( urlChanged(const KURL &) ) );
	
	QByteArray data, rec_data;
	QDataStream stream( rec_data, IO_ReadOnly );
	QCString type;
	QCString id = kapp->dcopClient()->appId();
	
	if( id.isEmpty() ) {
		kdDebug() << "Error in DCOP appId().\n";
		return;
	}
	
	if( !kapp->dcopClient()->call( 
	        id, "konqueror-mainwindow#1", "currentURL()", data,
		type, rec_data ) ) {
		kdDebug() << "Error in DCOP currentURL() send.\n";
		return;
	}
	
	QString str;
	stream >> str;
	this->urlChanged( KURL( str ) );
}

Details::~Details()
{
}

void Details::urlChanged(const KURL &url)
{
	mUrl = url;
	KFileItem *file = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, 
					 mUrl, false);
	
	if ( mUrl.fileName() != QString::null ) {
		lIcon->setPixmap( file->pixmap(22) );
		lName->setText( mUrl.fileName() );
		lIcon->show();
		lName->show();
	} else {
		lIcon->hide();
		lName->hide();
	}
	
	lType->setText( file->mimeComment() );
	
	if ( file->user() != QString::null ) {
		lUser->setText( file->user() + " : " + file->group() );
		lUser->show(); sUser->show();
		/* If we don't know the user:group, permissions got no 
                   meaning. */
		lPermissions->setText( file->permissionsString() );
		lPermissions->show(); sPermissions->show();
	} else {
		lUser->hide(); sUser->hide();
		lPermissions->hide(); sPermissions->hide();
	}
	
	if ( file->time(KIO::UDS_MODIFICATION_TIME) != (time_t)0 ) {
		lModified->setText( file->timeString() );
		lModified->show(); sModified->show();
	} else {
		lModified->hide(); sModified->hide();
	}
	
	if ( (file->isFile()) && (file->size() > 0) ) {
		float size = (float) file->size();
		QString s;
		if ( file->size() < 1024 ) 
			s = QString::number( (int) file->size() ) + i18n(" B");
		else if ( file->size() < 1048576 ) 
			s = QString::number( size / 1024.0, 'f', 1) + i18n(" KB");
		else if ( file->size() < 1073741824 ) 
			s = QString::number( size / 1048576.0, 'f', 1) + i18n(" MB");
		else 	s = QString::number( size / 1073741824.0, 'f', 1) + i18n(" GB");
	
		lSize->setText( s );
		lSize->show(); sSize->show();
	} else {
		lSize->hide(); sSize->hide();
	}
	
	
	for (int i=0; i < 6; i++) {
		lInfo[i]->hide();
		sInfo[i]->hide();
	}

	KFileMetaInfo metainfo = file->metaInfo();
	if ( metainfo.isEmpty() )
		return;
	QStringList list = metainfo.preferredKeys();
	QStringList::Iterator it = list.begin();
	for (int i=0;  i < 6  && it != list.end(); ++it ) {
		KFileMetaInfoItem item = metainfo.item( *it );
		if ( item.isValid() ) {
			sInfo[i]->setText( item.translatedKey() + QString(" : ") );
			lInfo[i]->setText( item.string() );
			lInfo[i]->show(); sInfo[i]->show();
			++i;
		}
	}
	
	delete file;	
}
	
#include "details.moc"

