/***************************************************************************
 *   Copyright (C) 2003 by Matteo Merli                                    *
 *   matteo@petaligrigi.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

/*
     Ideas and (much) code are taken from the "devices" kicker applet 
     by Kevin Ottens <ervin@tuxfamily.org>
     src code: kde/kdebase/kicker/applets/devices/
 */
 
#include "devices.h" 
#include "my_header.h"
#include "my_label.h"
#include "view.h"

#include <kdebug.h>
#include <klocale.h>
#include <qstringlist.h>

Devices::Devices(QWidget *parent, QBoxLayout *layout,
		 QString text, QString icon)
{
	mParent = (View *)parent;
	header = new MyHeader(mParent, layout, text, icon);
	
	mDirLister = new KDirLister();
	
	connect( mDirLister, SIGNAL( clear() ),
		 this, SLOT( slotClear() ) );
	connect( mDirLister, SIGNAL( newItems( const KFileItemList & ) ),
	         this, SLOT( slotNewItems( const KFileItemList & ) ) );
	connect( mDirLister, SIGNAL( deleteItem( KFileItem * ) ),
	         this, SLOT( slotDeleteItem( KFileItem * ) ) );
	connect( mDirLister, SIGNAL( refreshItems( const KFileItemList & ) ),
	         this, SLOT( slotRefreshItems( const KFileItemList & ) ) );
	
	reload();
	
	new MyLabel(mParent, header, i18n("All devices"),
		    "devices:/", "kcmdevices");
}

Devices::~Devices()
{
}

void Devices::slotClear()
{
	kdDebug() << " KSidebar :: slotClear \n";
	
	MyLabel *label = mLabelList.first();
	for ( ; label; label = mLabelList.next() ) {
		mLabelList.remove( label );
		label->hide();
		delete label;
	}
}

void Devices::slotNewItems( const KFileItemList &list )
{
	kdDebug() << " KSidebar :: slotNewItems \n";
	
	KFileItemListIterator it( list );
	for ( ; it.current(); ++it ) {
		KFileItem item = *it.current();
		kdDebug() << " KSidebar :: slotNewItems :: " << item.name() << "  -- "
			  << item.iconName() << "\n";
		MyLabel *label = new MyLabel( mParent, header, 
				      item.name(), item.url().url(), item.iconName() );
		label->show();
		mLabelList.append( label );
	}
}

void Devices::slotDeleteItem( KFileItem *item)
{
	kdDebug() << " KSidebar :: slotDeleteItem  :: " << item->name() << "\n";
	
	MyLabel *label = mLabelList.first();
	for ( ; label; label = mLabelList.next() ) {
		if ( KURL(label->link()) == item->url() ) {
			mLabelList.remove( label );
			delete label;
			break;
		}
	}
}

void Devices::slotRefreshItems( const KFileItemList &list)
{
	KFileItemListIterator it( list );
	for ( ; it.current(); ++it ) {
		
		kdDebug()<<" KSidebar :: slotRefreshItems:"<<(*it.current()).url().url()<<endl;
		
		it.current()->refresh();
		QString mimetype = (*it.current()).mimetype();
		bool found = false;
		
		MyLabel *label = mLabelList.first();
		for ( ; label; label = mLabelList.next() ) {
			if ( label->link() == (*it.current()).url().url() ) {
				label->update(  (*it.current()).name(),
						"devices:"+(*it.current()).url().path(),
						(*it.current()).iconName() );
				found = true;
				break;
			}
		}
		
		if ( !found ) {
			KFileItem item = *it.current();
			MyLabel *label = new MyLabel( mParent, header, item.name(),
					 item.url().url(), item.iconName() );
			label->show();
			mLabelList.append( label );
		}
	}
}

void Devices::reload()
{
	mDirLister->stop();
	
	QStringList list;
	
	list << "kdedevice/hdd_mounted";
	list << "kdedevice/hdd_unmounted";
	mDirLister->setMimeExcludeFilter( list );
	mDirLister->openURL( KURL("devices:/") );
}


#include "devices.moc"



