/***************************************************************************
 *   Copyright (C) 2003 by Matteo Merli                                    *
 *   matteo@petaligrigi.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
 

#include "my_header.h"
#include "flat_button.h"

#include <qfont.h>
#include <qlabel.h>
#include <qbutton.h>
#include <kglobal.h>
#include <kiconloader.h>
#include <kglobalsettings.h>

MyHeader::MyHeader(QWidget *parent, QBoxLayout *par_layout, 
	 QString text, QString icon)
	: mIsVisible(true),
          mParent( parent ),
	  sIcon( icon ),
	  std_color( /*KGlobalSettings::baseColor()*/parent->backgroundColor() ),
	  m_on( false )
{
	QVBoxLayout *lay = new QVBoxLayout( 0 );
	mFrame = new QFrame( parent );
	mFrame->setFrameStyle( QFrame::NoFrame );
	lineFrame = new QFrame( parent );
	lineFrame->setFrameStyle( QFrame::StyledPanel | QFrame::Raised );
	lay->addWidget( lineFrame );
	lay->addWidget( mFrame );

	par_layout->addSpacing(20);
	priv_layout = new QVBoxLayout( par_layout );
	
	btn = new FlatButton( parent );
		
	QFont boldFont;
	boldFont.setBold( true );
	boldFont.setPointSize( boldFont.pointSize() + 1 );

	mIcon = new QLabel( btn );
	mIcon->setFixedSize( 32, 32 );
	mIcon->setPixmap( KGlobal::iconLoader()->loadIcon( icon, 
			KIcon::Desktop, KIcon::SizeMedium) );
	btn->addWidget( mIcon );
	
	mLabel = new QLabel( text, btn );
	mLabel->setFont( boldFont );
	btn->addWidget( mLabel );

	connect(btn, SIGNAL( clicked() ),
	 	this, SLOT( hide_show() ));
	connect( btn, SIGNAL( mouseEnter() ),
		 this, SLOT( mouseOn() ));
	connect( btn, SIGNAL( mouseLeave() ),
		 this, SLOT( mouseOff() ));
	
	layout = new QVBoxLayout( mFrame );
	priv_layout->addWidget( btn );
	priv_layout->addLayout( lay );
}

MyHeader::~MyHeader()
{
}

void MyHeader::hide_show()
{
	QColor color = std_color;
	
	if ( mIsVisible ) {
		mIsVisible = false;
		mFrame->hide();
		lineFrame->hide();
		color = QColor( color.red() - 20, 
				color.green() - 20,
				color.blue() - 20);
	} else {
		mIsVisible = true;
		lineFrame->show();
		mFrame->show();
	}

	if (m_on) 
		color = QColor( color.red() - 10, 
				color.green() - 10,
				color.blue() - 10);
	
#if 0
	mLabel->setBackgroundColor( color );
	mIcon->setBackgroundColor( color );
#endif
}

void MyHeader::setVisible(bool f)
{
	mIsVisible = !f;
	hide_show();
}

void MyHeader::hide()
{
	mIcon->hide();
	mLabel->hide();
	mFrame->hide();
	lineFrame->hide();
}

void MyHeader::show()
{
	mIcon->show();
	mLabel->show();
	if ( mIsVisible ) {
		lineFrame->show();
		mFrame->show();
	}
}


void MyHeader::mouseOn()
{
	if ( m_on )
		return;
#if 0
	QColor color( mLabel->backgroundColor() );
	color = QColor(color.red()   - 10,
		       color.green() - 10,
		       color.blue()  - 10 );
	mLabel->setBackgroundColor( color );
	mIcon->setBackgroundColor( color );
#endif
	mIcon->setPixmap( KGlobal::iconLoader()->loadIcon( sIcon , KIcon::Desktop, 
				KIcon::SizeMedium, KIcon::ActiveState ));
	m_on = true;
}

void MyHeader::mouseOff()
{
	if ( !m_on )
		return;
#if 0
	QColor color( mLabel->backgroundColor() );
	color = QColor(color.red()   + 10,
		       color.green() + 10,
		       color.blue()  + 10 );
	mLabel->setBackgroundColor( color );
	mIcon->setBackgroundColor( color );
#endif
	mIcon->setPixmap( KGlobal::iconLoader()->loadIcon( sIcon , KIcon::Desktop,
			 KIcon::SizeMedium, KIcon::DefaultState ));
	m_on = false;
}


#include "my_header.moc"
