/***************************************************************************
 *   Copyright (C) 2003 by Matteo Merli                                    *
 *   matteo@petaligrigi.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
 

#include "my_label.h"
#include "flat_button.h"

#include <qlabel.h>
#include <kglobal.h>
#include <kiconloader.h>
#include <kglobalsettings.h>

MyLabel::MyLabel(View *parent, MyHeader *header, QString text, 
		 QString link, QString icon)
{
	m_link = link;
	m_parent = parent;
	use_action = false;
	sIcon = icon;
	QHBoxLayout *hbox = new QHBoxLayout( 0 );
	hbox->addSpacing(20);
	
	btn = new FlatButton( header->mFrame );
	mIcon = new QLabel( btn );
	mIcon->setFixedSize( 22, 22 );
	mIcon->setPixmap( KGlobal::iconLoader()->loadIcon( icon , KIcon::Small ));
	btn->addWidget( mIcon );

	mLabel = new KURLLabel( link, text, btn );
	mLabel->setUnderline( false );
	mLabel->setFloat();
	mLabel->setHighlightedColor( KGlobalSettings::textColor() );
	btn->addWidget( mLabel );
		
	connect( btn, SIGNAL( clicked() ),
		 this, SLOT( clicked() ) );
	connect( btn, SIGNAL( mouseEnter() ),
		 this, SLOT( mouseOn() ));
	connect( btn, SIGNAL( mouseLeave() ),
		 this, SLOT( mouseOff() ));
	
	
	hbox->addWidget( btn );
	header->layout->addLayout( hbox );
}


MyLabel::~MyLabel()
{
}

void MyLabel::clicked()
{
	if ( use_action ) 
		emit click_action( m_act );
	else m_parent->clicked( m_link );
}

void MyLabel::update(QString text, QString link, QString icon)
{
	mLabel->setText( text );
	mLabel->setURL( link );
	mIcon->setPixmap( KGlobal::iconLoader()->loadIcon( icon , KIcon::Small, 
							   0, KIcon::DefaultState ));
	sIcon = icon;
}

void MyLabel::mouseOn()
{
#if 0
	QColor color( mLabel->backgroundColor() );
	color = QColor(color.red()   - 10,
		       color.green() - 10,
		       color.blue()  - 10 );
	mLabel->setBackgroundColor( color );
	mIcon->setBackgroundColor( color );
#endif
	mIcon->setPixmap( KGlobal::iconLoader()->loadIcon( sIcon , 
			KIcon::Small, 0, KIcon::ActiveState ));
}

void MyLabel::mouseOff()
{
#if 0
	QColor color( mLabel->backgroundColor() );
	color = QColor(color.red()   + 10,
		       color.green() + 10,
		       color.blue()  + 10 );
	mLabel->setBackgroundColor( color );
	mIcon->setBackgroundColor( color );
#endif
	mIcon->setPixmap( KGlobal::iconLoader()->loadIcon( sIcon , 
			KIcon::Small, 0, KIcon::DefaultState ));
}

void MyLabel::hide()
{
	if ( btn )
		btn->hide();
}

void MyLabel::show()
{
	if ( btn )
		btn->show();
}

void MyLabel::setAction(s_action &act)
{
	m_act = act;
	use_action = true;
}


#include "my_label.moc"

